@@ -1,12 +1,11 @@
 import json
 
 import requests
-from betterproto import Casing
 
 from maitai._config import config
 from maitai._utils import __version__ as version
 from maitai._utils import required_args
-from maitai_gen.application import ApplicationContext
+from maitai.models.application import ApplicationContext
 
 
 class ContextManager:
@@ -27,17 +26,21 @@ class ContextManager:
         if context_body and file_path:
             raise ValueError("Only one of context_body and file can be specified")
 
-        context = ApplicationContext()
-        context.reference = reference
         if file_path:
             s3_path = self.upload_context_file(file_path).get("s3_path")
             if not s3_path:
                 raise Exception("Failed to upload context")
-            context.context_type = "FILE"
-            context.context_path = s3_path
+            context_type = "FILE"
+            context_path = s3_path
         else:
-            context.context_body = context_body
-            context.context_type = "TEXT"
+            context_type = "TEXT"
+            context_path = None
+        context = ApplicationContext(
+            reference=reference,
+            context_type=context_type,
+            context_path=context_path,
+            context_body=context_body,
+        )
 
         host = config.maitai_host
         url = f"{host}/context/application"
@@ -52,7 +55,7 @@ class ContextManager:
             data=json.dumps(
                 {
                     "application_ref_name": application,
-                    "context": context.to_pydict(casing=Casing.SNAKE),
+                    "context": context.model_dump(),
                 }
             ),
         )
